@@ -34,6 +34,20 @@ $pdo = $MySQLMgmt->getMySQLConnection();
                     <h6><i class="bi bi-exclamation-triangle"></i> Early Release Feature</h6>
                     <p class="mb-0">This cPanel backup import feature is currently in early release. While functional, please test with non-critical data first and report any issues you encounter.</p>
                 </div>
+                
+                <?php if (AUTH_USER === 'root'): ?>
+                <!-- Root User - Target User Selection -->
+                <div class="alert alert-info">
+                    <h6><i class="bi bi-person-gear"></i> Root User - Import for Another User</h6>
+                    <div class="mb-3">
+                        <label for="target_user_select" class="form-label">Select Target User</label>
+                        <select class="form-select" id="target_user_select" required>
+                            <option value="">Loading users...</option>
+                        </select>
+                        <div class="form-text">Select the user account to import the cPanel backup into.</div>
+                    </div>
+                </div>
+                <?php endif; ?>
             </div>
         </div>
 
@@ -206,8 +220,47 @@ $pdo = $MySQLMgmt->getMySQLConnection();
         // Load backup files on page load
         document.addEventListener('DOMContentLoaded', function() {
             refreshBackupFiles();
+            <?php if (AUTH_USER === 'root'): ?>
+            loadUsers();
+            <?php endif; ?>
         });
 
+        <?php if (AUTH_USER === 'root'): ?>
+        // Load users for root user
+        async function loadUsers() {
+            try {
+                const response = await fetch('/api/cpanel-import-ajax.php', {
+                    method: 'POST',
+                    headers: {
+                        'Content-Type': 'application/x-www-form-urlencoded',
+                    },
+                    body: new URLSearchParams({
+                        action: 'list_users',
+                        nonce: nonce
+                    })
+                });
+
+                const result = await response.json();
+                const userSelect = document.getElementById('target_user_select');
+
+                if (result.success) {
+                    userSelect.innerHTML = '<option value="">Select a user...</option>';
+                    result.users.forEach(user => {
+                        const option = document.createElement('option');
+                        option.value = user;
+                        option.textContent = user;
+                        userSelect.appendChild(option);
+                    });
+                } else {
+                    userSelect.innerHTML = '<option value="">Failed to load users</option>';
+                }
+            } catch (error) {
+                console.error('Failed to load users:', error);
+                document.getElementById('target_user_select').innerHTML = '<option value="">Error loading users</option>';
+            }
+        }
+        <?php endif; ?>
+
         // Refresh backup files list
         async function refreshBackupFiles() {
             try {
@@ -317,17 +370,32 @@ $pdo = $MySQLMgmt->getMySQLConnection();
         });
 
         async function startImport(backupFilePath) {
+            <?php if (AUTH_USER === 'root'): ?>
+            // Check if target user is selected for root
+            const targetUserSelect = document.getElementById('target_user_select');
+            if (!targetUserSelect.value) {
+                alert('Please select a target user for the import');
+                return;
+            }
+            <?php endif; ?>
+            
             try {
+                const params = {
+                    action: 'start_import',
+                    backup_file: backupFilePath,
+                    nonce: nonce
+                };
+                
+                <?php if (AUTH_USER === 'root'): ?>
+                params.target_user = targetUserSelect.value;
+                <?php endif; ?>
+                
                 const response = await fetch('/api/cpanel-import-ajax.php', {
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
                     },
-                    body: new URLSearchParams({
-                        action: 'start_import',
-                        backup_file: backupFilePath,
-                        nonce: nonce
-                    })
+                    body: new URLSearchParams(params)
                 });
 
                 const result = await response.json();
